Author: Institut für Wissensmedien (Verwaltung)

### Antrag zur Benutzungsberechtigung für Rechner am Institut für Wissensmedien

| Name | Vorname | Titel
Antragsteller | Foo | Bar | Prof.
Status | Trainee
Forschungsbereich | Kitchensink
Vorgesetzter |

Ich, der Antragsteller, versichere hiermit:

- dass ich die mir zur Benutzung zur Verfügung gestellten Rechenanlagen ausschließlich zu den vereinbarten Zwecken verwende,
- dass ich alle mir zur Benutzung zur Verfügung gestellten Rechenanlagen samt zugehöriger Peripherie pfleglich behandele und ohne besondere Genehmigung keinerlei Eingriffe in deren Hard- oder Software vornehme,
- dass ich keine der mir zugestandenen Benutzungsmöglichkeiten auf andere Personen übertrage,
- dass ich mein Passwort keiner anderen Person mitteile und der mir zugeteilte Datenbereich nicht durch Dritte mitgenutzt wird,
- dass ich fremden oder unbefugten Personen keinen Zutritt zu institutseigenen Räumen verschaffe und die Türen zu diesen Räumen geschlossen halte,
- dass ich keine mir bekannt gewordenen vertraulichen Informationen weitergebe,
- dass ich mich betreffende Benutzungsordnungen anderer universitärer Einrichtungen (ZDV, etc.) einhalte.

Mir ist bekannt:

- dass nach dem Ausscheiden aus dem Institut die Benutzungsberechtigungen verfallen und zugehörige Daten gelöscht werden (eine Verlängerung der Nutzungsrechte muss rechtzeitig beantragt werden),
- dass die Urheber- und Patentrechte für Software zu wahren sind, und dass deren Verletzung nach den Bestimmungen des Zivilrechts schadenersatzpflichtig macht, strafrechtlich mit Freiheitsstrafe oder Geldstrafe verfolgt wird und darüber hinaus eine Verurteilung wegen Diebstahls, Unterschlagung und Untreue in Betracht kommen,
- dass keine unzulässigen Kopien von mir zugänglich gemachter Software und Handbüchern angefertigt werden dürfen,
- dass die Verarbeitung personenbezogener Daten im Sinne des Landesdatenschutz-Gesetzes auf den Anlagen des Institutes genehmigungspflichtig ist und beantragt werden muss,
- dass ein Verstoß gegen diese Auflagen einen Entzug der mir zugestandenen Benutzungsrechte zur Folge haben und neben straf-, dienst- und zivilrechtlichen Schritten auch weitere Folgen nach sich ziehen kann (Kündigung des Arbeitsvertrages).

| (Datum, Unterschrift des Antragstellers)

Mit der Aufgabenstellung werden Dienstaufgaben aus Forschung, Lehre und Verwaltung überwiegend öffentlich geförderter Einrichtungen verfolgt; es wird kein gewerblicher Nutzen daraus gezogen.

Nutzername | tkurbad | Kennwort |
Firstclass Nutzername | t.kurbad | Kennwort |
Email-Adresse | nospam@please.org | Rechnername |
Raumnummer | 08/15 | Telefonnummer | 4711